# `Calculators`

::: molfeat.calc

----

#### Serializable Calculator are the base abstract class for implementing your calculators.

::: molfeat.calc.base

----

### `Fingerprints`
::: molfeat.calc.fingerprints

----

### `CATS`
::: molfeat.calc.cats

----

### `Pharmacophore`
::: molfeat.calc.pharmacophore

----

### `Scaffold Keys`
::: molfeat.calc.skeys

----

### `Shape`
::: molfeat.calc.shape

----

### `Atoms Featurizer`
::: molfeat.calc.atom

----

### `Bonds Featurizer`
::: molfeat.calc.bond

----
